@@ -256,7 +256,7 @@ def setup_hyp(experiment=None, data_yaml_path=None, config_path= None,  params={
 
     opt.resume = False
     opt.bucket = ''
-    opt.device = f'cuda:{torch.current_device()}' if torch.cuda.is_available() else 'cpu'
+    opt.device = f'cuda:{torch.cuda.current_device()}' if torch.cuda.is_available() else 'cpu'
     opt.local_rank = -1 
     opt.log_imgs = 4
     opt.workers = 4
